Summary:            Palo MOLAP Database Server
Name:               palo
Version:            5.1
Release:            4%{?dist}
License:            GPLv2
Group:              Applications/Databases
Source:             https://svn.code.sf.net/p/%{name}/code/molap/server/%{version}/
Patch0:             palo-5.1.4-cmake.patch
#Provide a systemd unit to start palo on boot: not provide by source tree
#http://www.jedox.com/community/palo-forum/index.php?page=Thread&threadID=4597&s=f5e82bfa901352bc4e26869347bf8a4d7b6466e7
Patch1:             palo-5.1.4-systemd-unit.patch
URL:                http://www.jedox.com/community/palo-forum/
BuildRequires:      subversion
BuildRequires:      cmake
BuildRequires:      zlib
BuildRequires:      openssl
BuildRequires:      boost
BuildRequires:      icu
BuildRequires:      gperftools
BuildRequires:      gettext

%description
Palo is a cell-oriented, multi-dimensional in-memory OLAP server typically used
for analysis and data consolidation. Multi-dimensional data can be queried 
interactively and written back for further consolidation. The server stores and
manipulates data in momeory. Bespoke Java, PHP, C/C++, and .NET clients can 
access the palo database via an API or plug-in modules are available for 
spreadsheet applications.

%prep
#Clean-up the BUILD folder - this seems to cause svn to fail with E125001
#rm -rf %{_builddir}
#Get the server source code
svn co https://svn.code.sf.net/p/%{name}/code/molap/server/%{version}/
#Patch the source to include the systemd unit
%patch0 -p0
%patch1 -p0


%build
#Cmake fails without the generic .so files for boost, so create them
#sudo ln -s %{_libdir}/libboost_system.so.1.55.0 %{_libdir}/libboost_system-mt.so
#sudo ln -s %{_libdir}/libboost_thread.so.1.55.0 %{_libdir}/libboost_thread-mt.so
#sudo ln -s %{_libdir}/libboost_regex.so.1.55.0 %{_libdir}/libboost_regex-mt.so
#Create a build directory for cmake
mkdir --parents %{_builddir}/build
cd %{_builddir}/build
#Enable position-independent code (PIC)
%global _hardened_build 1
#Use cmake and make to build the server
#%cmake -DPROJECT_BUILD_TYPE=Release -DLIB_BOOST_ROOT_DIR=%{_libdir} -DLIB_OPENSSL_ROOT_DIR=%{_libdir} -DLIB_PERFTOOLS_ROOT_DIR=%{_libdir} -DLIB_ICU_ROOT_DIR=%{_libdir} -DLIB_ZLIB_ROOT_DIR=%{_libdir} ../%{version}/
%cmake ../%{version}/
make %{?_smp_mflags}

%install
#Clean-up the destination BUILDROOT folder
rm -rf %{buildroot}
#Create the folder structure
mkdir --parents %{buildroot}%{_bindir}
mkdir --parents %{buildroot}%{_libdir}
mkdir --parents %{buildroot}%{_sysconfdir}
mkdir --parents %{buildroot}%{_sharedstatedir}/%{name}/Data
mkdir --parents %{buildroot}%{_unitdir}
#mkdir --parents %{buildroot}%{_docdir}/%{name}
install --strip --mode=0755 %{_builddir}/build/usr/bin/%{name} %{buildroot}%{_bindir}
install --strip --mode=0755 %{_builddir}/build/usr/lib64/libhttps.%{name}.* %{buildroot}%{_libdir}
#Copy accross the runtime configuration file
install %{_builddir}/%{version}/%{name}.ini.sample %{buildroot}%{_sysconfdir}/%{name}.ini
#Copy the the palo.service file
#NOTE: the systemd unit file is provided by the package maintainer as Patch0
install --mode=0644 %{_builddir}/%{version}/%{name}.service %{buildroot}%{_unitdir}
#Copy the documentation files: README, CHANGELOG and LICENSE
#install --mode=0644 %{_builddir}/%{version}/README %{buildroot}%{_docdir}/%{name}
#install --mode=0644 %{_builddir}/%{version}/CHANGELOG %{buildroot}%{_docdir}/%{name}
#install --mode=0644 %{_builddir}/%{version}/LICENSE %{buildroot}%{_docdir}/%{name}

#Locate all of the locale files and create palo.lang in %{_builddir}
#Although gettext is used in the application no .mo or .po files are provided
#To avoid "No translations found " error and exit, don't call %find_lang
#%find_lang %{name}

#Ensure the ldconfig is called on install and uninstall so the .so's work as expected
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

#This does not seem to work!
#%check
#ctest -V %{?_smp_mflags}

#As we did not find_lang
#%files -f %{name}.lang
%files
%defattr(-,root,root,-)
#Documentation files as provided by upstream
%doc ./%{version}/README ./%{version}/CHANGELOG ./%{version}/LICENSE
#%{_docdir}/%{name}/README
#%{_builddir}/%{version}/README
#%{_docdir}/%{name}/CHANGELOG
#%{_builddir}/%{version}/CHANGELOG
#%{_docdir}/%{name}/LICENSE
#%{_builddir}/%{version}/LICENSE
#Files owned by the package
%{_bindir}/%{name}
%{_libdir}/libhttps.%{name}.*
#Directories owned by the package
%{_sharedstatedir}/%{name}
#Tag the config files so they don't get overridden
%config(noreplace) %{_sysconfdir}/%{name}.ini
%config(noreplace) %{_unitdir}/%{name}.service

%changelog
* Sun Mar 29 2015 Michael Arnold <myk321@gmail.com> - 5.1.4
- Created initial palo.spec file based on https://fedoraproject.org/wiki/How_to_create_an_RPM_package

